/*
The following licence has been copied from
http://www.opensource.org/licenses/mit-license.html

Copyright (c) 2000, Peter Arthur Loeb

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/
package com.palserv.XMidi;

import org.apache.xerces.parsers.DOMParser;
import org.apache.xerces.framework.XMLParser;
import org.apache.xerces.dom.*;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import org.w3c.dom.Document;
import java.io.*;

/**
 * This class allows the Xerces XML parser
 * to be used with the XMidi package.
 * For more details see the
 * {@link com.palserv.XMidi.XSilfide XSilfide} class
 * @author Peter Arthur Loeb
*/
public class Xerces implements Parser {
	DOMParser xd;

/**
 * The default constructor (which takes no arguments
 * and does nothing) is necessary.
 * It is used by the XM class to load this class.
*/
	public Xerces() {}

/**
 * This is the conversion routine.	It is invoked from
 * the XM class to parse the XML file.
 * @param String fid - file id of XML file to parse.
 * @return Document as in com.w3c.dom.Document or a sub-class.
*/
	public Document parseXML(String fid) {
		xd = new DOMParser();

		FileInputStream fis = null;
		try {
			fis = new FileInputStream(fid);
		} catch(FileNotFoundException e) {
			System.err.println("Error opening: "+fid+": "+e.getMessage());
		}

		InputSource xis = new InputSource(fis);
		try {
			xd.parse(xis);
		} catch(SAXException e) {
			System.err.println("Error parsing: "+fid+": "+e.getMessage());
		} catch(IOException e) {
			System.err.println("IO Error parsing: "+fid+": "+e.getMessage());
		}
		Document xDoc = (Document)xd.getDocument();

		try {
			fis.close();
		} catch(IOException e) {
			System.err.println("Error closing: "+fid+": "+e.getMessage());
		}

		return xDoc;
	}


/**
 * This routine simply returns a DOM Document.
 * @return Document as in com.w3c.dom.Document or a sub-class.
*/
	public Document getNewDoc() {
		Document xDoc = (Document) new DocumentImpl();
		return xDoc;
	}
}
